% Generated by roxygen2: do not edit by hand
% Please edit documentation in R/solve.R
\name{solve-methods}
\alias{solve-methods}
\alias{solve}
\alias{solve,GWoodburyMatrix,missing-method}
\alias{solve,GWoodburyMatrix,ANY-method}
\alias{solve,SWoodburyMatrix,missing-method}
\alias{solve,SWoodburyMatrix,ANY-method}
\title{Solve methods for \code{WoodburyMatrix} objects}
\usage{
\S4method{solve}{GWoodburyMatrix,missing}(a)

\S4method{solve}{GWoodburyMatrix,ANY}(a, b)

\S4method{solve}{SWoodburyMatrix,missing}(a)

\S4method{solve}{SWoodburyMatrix,ANY}(a, b)
}
\arguments{
\item{a}{\code{WoodburyMatrix} object.}

\item{b}{Matrix, vector, or similar (needs to be compatible with the
submatrices \code{a@A} and \code{a@V} or \code{a@X} that define the
\code{WoodburyMatrix}).}
}
\value{
The solution to the linear system, or the inverse of the matrix. The
class of the return value will be a subclass of
\code{\linkS4class{Matrix}}, with the specific subclass determined
by \code{a} and \code{b}.
}
\description{
Methods based on \code{\link{solve}} to solve a linear system of equations
involving \code{\linkS4class{WoodburyMatrix}} objects. These methods take
advantage of the Woodbury matrix identity and therefore can be much more
time and memory efficient than forming the matrix directly.

Calling this function while omitting the \code{b} argument returns the
inverse of \code{a}. This is NOT recommended, since it removes any benefit
from using an implicit representation of \code{a}.
}
\section{Functions}{
\itemize{
\item \code{solve,GWoodburyMatrix,missing-method}: Invert the matrix

\item \code{solve,GWoodburyMatrix,ANY-method}: Solve the linear system

\item \code{solve,SWoodburyMatrix,missing-method}: Invert the symmetric matrix

\item \code{solve,SWoodburyMatrix,ANY-method}: Solve the linear system
}}

\seealso{
\link{WoodburyMatrix}, \linkS4class{WoodburyMatrix}
}
